==> centreon-web-23.10.28.tar.gz: centreon-web-23.10.28/www/install/menu_translation.php <==
<?php

/*
 * Copyright 2005-2015 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */

echo _("About");
echo _("Access Groups");
echo _("Access List");
echo _("ACL");
echo _("Actions Access");
echo _("Add Widget");
echo _("Administration");
echo _("Advanced Logs");
echo _("Auto Discovery");
echo _("Availability");
echo _("Boolean Rules");
echo _("Broker configuration");
echo _("Broker Statistics");
echo _("Business Activity");
echo _("Business Views");
echo _("By Host");
echo _("By Host Group");
echo _("By Service Group");
echo _("By Status");
echo _("Categories");
echo _("CentCore");
echo _("Centreon Map");
echo _("Centreon Map Client (admin)");
echo _("Centreon Map Client (user)");
echo _("Centreon UI");
echo _("Checks");
echo _("Commands");
echo _("Comments");
echo _("Configuration");
echo _("Connectors");
echo _("Contact Groups");
echo _("Contact Templates");
echo _("Contacts / Users");
echo _("CSS");
echo _("Curves");
echo _("Custom Views");
echo _("Dashboards");
echo _("Data");
echo _("Databases");
echo _("Debug");
echo _("Default Settings");
echo _("Dependencies");
echo _("Discovery");
echo _("Downtimes");
echo _("Edit");
echo _("Engine configuration");
echo _("Escalations");
echo _("Event Logs");
echo _("Extensions");
echo _("General Access");
echo _("Generate");
echo _("Geolocation");
echo _("Graphs");
echo _("Group");
echo _("Help");
echo _("Home");
echo _("Host Groups");
echo _("Host Templates");
echo _("Hostgroups Summary");
echo _("Hosts");
echo _("Images");
echo _("Indicators");
echo _("Knowledge Base");
echo _("LDAP");
echo _("Logs");
echo _("Management");
echo _("Manufacturer");
echo _("Map");
echo _("Media");
echo _("Menus Access");
echo _("Meta Services");
echo _("Metrics");
echo _("MIBs");
echo _("Miscellaneous");
echo _("Modules");
echo _("Modules Options");
echo _("Monitoring");
echo _("Monitoring Engine");
echo _("My Account");
echo _("Notifications");
echo _("Options");
echo _("Overview");
echo _("Parameters");
echo _("Performance Management");
echo _("Performances");
echo _("Monitoring Connectors");
echo _("Poller Statistics");
echo _("Pollers");
echo _("Reload ACL");
echo _("Reporting");
echo _("Resources");
echo _("Resources Access");
echo _("Rotation");
echo _("RRDTool");
echo _("Rules");
echo _("Scan");
echo _("Server Status");
echo _("Service Groups");
echo _("Service Templates");
echo _("Services");
echo _("Services by host");
echo _("Services by host group");
echo _("Services by Hostgroup");
echo _("Services by Servicegroup");
echo _("Services Grid");
echo _("Sessions");
echo _("Setup");
echo _("Share");
echo _("SNMP Traps");
echo _("Status Details");
echo _("System Logs");
echo _("Templates");
echo _("Time Periods");
echo _("Troubleshooter");
echo _("User Settings");
echo _("Users");
echo _("Users Access");
echo _("Views");
echo _("Views Restrictions");
echo _("Virtuals");
echo _("Visualisation");
echo _("Widgets");
echo _("Wizard");
echo _("WizardAjax");

==> centreon-web-24.11.0.tar.gz: centreon-web-24.11.0/www/install/menu_translation.php <==
<?php

/*
 * Copyright 2005-2015 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */
 
echo _("About");
echo _("Access Groups");
echo _("Access List");
echo _("ACL");
echo _("Actions Access");
echo _("Add Widget");
echo _("Administration");
echo _("Advanced Logs");
echo _("Auto Discovery");
echo _("Availability");
echo _("Boolean Rules");
echo _("Broker configuration");
echo _("Broker Statistics");
echo _("Business Activity");
echo _("Business Views");
echo _("By Host");
echo _("By Host Group");
echo _("By Service Group");
echo _("By Status");
echo _("Categories");
echo _("CentCore");
echo _("Centreon Map");
echo _("Centreon Map Client (admin)");
echo _("Centreon Map Client (user)");
echo _("Centreon UI");
echo _("Checks");
echo _("Commands");
echo _("Comments");
echo _("Configuration");
echo _("Connectors");
echo _("Contact Groups");
echo _("Contact Templates");
echo _("Contacts / Users");
echo _("CSS");
echo _("Curves");
echo _("Custom Views");
echo _("Dashboards");
echo _("Data");
echo _("Databases");
echo _("Debug");
echo _("Default Settings");
echo _("Dependencies");
echo _("Discovery");
echo _("Downtimes");
echo _("Edit");
echo _("Engine configuration");
echo _("Escalations");
echo _("Event Logs");
echo _("Extensions");
echo _("General Access");
echo _("Generate");
echo _("Geolocation");
echo _("Graphs");
echo _("Group");
echo _("Help");
echo _("Home");
echo _("Host Groups");
echo _("Host Templates");
echo _("Hostgroups Summary");
echo _("Hosts");
echo _("Images");
echo _("Indicators");
echo _("Knowledge Base");
echo _("LDAP");
echo _("Logs");
echo _("Management");
echo _("Manufacturer");
echo _("Map");
echo _("Media");
echo _("Menus Access");
echo _("Meta Services");
echo _("Metrics");
echo _("MIBs");
echo _("Miscellaneous");
echo _("Modules");
echo _("Modules Options");
echo _("Monitoring");
echo _("Monitoring Engine");
echo _("My Account");
echo _("Notifications");
echo _("Options");
echo _("Overview");
echo _("Parameters");
echo _("Performance Management");
echo _("Performances");
echo _("Monitoring Connectors Manager");
echo _("Poller Statistics");
echo _("Pollers");
echo _("Reload ACL");
echo _("Reporting");
echo _("Resources");
echo _("Resources Access");
echo _("Rotation");
echo _("RRDTool");
echo _("Rules");
echo _("Scan");
echo _("Server Status");
echo _("Service Groups");
echo _("Service Templates");
echo _("Services");
echo _("Services by host");
echo _("Services by host group");
echo _("Services by Hostgroup");
echo _("Services by Servicegroup");
echo _("Services Grid");
echo _("Sessions");
echo _("Setup");
echo _("Share");
echo _("SNMP Traps");
echo _("Status Details");
echo _("System Logs");
echo _("Templates");
echo _("Time Periods");
echo _("Troubleshooter");
echo _("User Settings");
echo _("Users");
echo _("Users Access");
echo _("Views");
echo _("Views Restrictions");
echo _("Virtuals");
echo _("Visualisation");
echo _("Widgets");
echo _("Wizard");
echo _("WizardAjax");
